pub fn solver_kind_str(detected: &DetectedCaptcha) -> Option<&'static str>Expand description
Convert DetectedCaptcha to a string kind for the solver layer. Returns None for types that can’t be solved externally.
pub fn solver_kind_str(detected: &DetectedCaptcha) -> Option<&'static str>Convert DetectedCaptcha to a string kind for the solver layer. Returns None for types that can’t be solved externally.